@@ -99,7 +99,7 @@ class dyagram:
         try:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering LLDP Neighbors - START")
             resp = self._discover_lldp_neighbors_by_restconf(device)
-            if not resp or resp.status_code != 200:
+            if not resp:
                 raise
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering LLDP Neighbors - SUCCESSFUL")
         except:
@@ -587,31 +587,36 @@ class dyagram:
 
         if not netmiko_session and restconf_session:
             try:
-                self.log.info(f"DEVICE: {restconf_session.base_url} - RESTCONF_OPENCONFIG : Querying for hostname - START")
-                resp = restconf_session.get(f"{restconf_session.base_url}/openconfig-system:system/config/name")
+                device = re.search('\d+\.\d+\.\d+\.\d+', restconf_session.base_url).group(1)
+            except:
+                device = restconf_session.base_url
+
+            try:
+                self.log.info(f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying for hostname - START")
+                resp = restconf_session.get(f"{device}/openconfig-system:system/config/name")
                 if resp.status_code == 200:
-                    self.log.info(f"DEVICE: {restconf_session.base_url} - RESTCONF_OPENCONFIG : Querying hostname - SUCCESSFUL")
+                    self.log.info(f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying hostname - SUCCESSFUL")
                     return resp.json()['hostname']
                 if resp.status_code != 200:
                     self.log.info(
-                        f"DEVICE: {restconf_session.base_url} - RESTCONF_OPENCONFIG : Querying hostname - FAILURE")
+                        f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying hostname - FAILURE")
                     # try nexus TEMPORARY
                     self.log.info(
-                        f"DEVICE: {restconf_session.base_url} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - START")
-                    resp = restconf_session.get(f"{restconf_session.base_url}/Cisco-NX-OS-device:System/name")
+                        f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - START")
+                    resp = restconf_session.get(f"{device}/Cisco-NX-OS-device:System/name")
 
                     if resp.status_code == 200:
                         self.log.info(
-                            f"DEVICE: {restconf_session.base_url} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - SUCCESSFUL")
+                            f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - SUCCESSFUL")
                         return resp.json()['name']
                     self.log.info(
-                        f"DEVICE: {restconf_session.base_url} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - FAILURE")
+                        f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - FAILURE")
 
             except Exception:
 
                 tb = self.get_traceback()
                 self.log.info(
-                    f"DEVICE: {restconf_session.base_url} - RESTCONF_OPENCONFIG_AND_NXOS_OS_DEVICE_YANG_CATCHALL : Querying hostname - FAILURE - TB: {tb}")
+                    f"DEVICE: {device} - RESTCONF_OPENCONFIG_AND_NXOS_OS_DEVICE_YANG_CATCHALL : Querying hostname - FAILURE - TB: {tb}")
 
         else:
             self.log.info(f"DEVICE: {netmiko_session['host']} - SSH : Querying for hostname - START")
@@ -670,13 +675,11 @@ def main():
     parser = argparse.ArgumentParser()
 
     parser.add_argument('dyagram_args', nargs='*')
+    parser.add_argument("-v", action='store_true', dest='verbose')
 
     args = parser.parse_args()
 
-    verbose = False
-    if '-v' or '--verbose' in args.dyagram_args:
-        verbose = True
-
+    verbose = args.verbose
 
     if args.dyagram_args[0].lower() == "init":
         from dyagram.initialize import initialize
